// (C) Copyright 2013 Hewlett-Packard Development Company, L.P.
/**
 * @type (GroupReportsView)
 * This is a view class for Group Reports menu option.
 */

define(['hpsum/presenter/group/GroupPresenter',
	'hpsum/presenter/node/NodePresenter',
    'hp/core/Router',
    'hp/core/UrlFragment',
    'hp/view/FormStateView',
    'hp/core/HelpMenu',
	'hp/core/Localizer',
	'hp/core/Notifications',
	'hp/view/DialogView',
	'hp/model/Session',
    'jquery',
    'hp/lib/jquery.hpStackedPanels',
	'lib/jquery.jstree',
    'lib/jquery.selectBox'],
function(groupPresenter, presenter, router,urlFragment, FormStateView, helpMenu, localizer, notifications, DialogView,session) {"use strict";

	var GroupReportsShowView = ( function() {
			var FORM = '#hpsum-groups-reports-form',
			    RESET = '#hpsum-groups-reset',
			    CANCEL = '#hpsum-groups-reports-close',
			    GENERATE = '#hpsum-groups-reports-generate',
			    PANEL_SELECTOR = '#hpsum-group-reports-panel-selector',
			    PANELS = '#hpsum-group-reports-panels',
			    TYPE = '#hpsum-group-reports-type',
			    ROUTE_PREFIX = '/group/reports',
				PATH = '#hpsum-location-path',
				BROWSE_OK='#hp-report-add-ok',
				BROWSE_CANCEL='#browse-dialog-cancel',
				BROWSE_BUTTON = '#hpsum-browse-location',
				BROWSE_TREE = '#browse',
				BROWSE_DIALOG = '#hpsum-browse-dialog',
				INFO_DIALOG = '#hpsum-info-dialog',
				BROWSE_LOCATION_ERROR = '#hpsum-invalid-location-error',
			    FIRMWARECHECKBOX = '#hpsum-group-reports-firmware',
			    INSTALLABLECHECKBOX = '#hpsum-group-reports-installable',
			    FAILEDDEPCHECKBOX = '#hpsum-group-reports-faileddep',
			    INSTALLEDCHECKBOX = '#hpsum-group-reports-installed',
			    COMBINEDCHECKBOX = '#hpsum-group-reports-combined',
			    REPORTFORMATHTML = '#hpsum-group-reports-html',
			    REPORTFORMATXML = '#hpsum-group-reports-xml',
			    REPORTFORMATCSV = '#hpsum-group-reports-csv',
			    RUNBACKCHECKBOX = '#chkbox-runbackReport',
			    TITLE = '#hpsum-group-reports-title',
			    SPLASH_DIALOG = '#hpsum-report-wait-dialog',
			    SPLASH_SPINNER = '#hpsum-report-spinner',
			    REPORTS_TABLE = '#hpsum-reports-table';

			function GroupReportsShowView() {
				var groupItem = null,
				    timer = null,
				    inProgressTimer = null,
				    inProgressReportId = null,
				    reportWaitDialog,
				    allReportsDialog,
				    deleteInfoDialog,
				    deleteReportId,
					infoDialog,
					browseDialogContents,
					rept_path,
				    generateInProgress = false;
				    
				function reset() {
					$(FIRMWARECHECKBOX).attr('checked', true);
					$(FIRMWARECHECKBOX).attr('disabled', false);
					$(FIRMWARECHECKBOX).trigger('change');
					
					$(INSTALLABLECHECKBOX).attr('checked', true);
					$(INSTALLABLECHECKBOX).attr('disabled', false);
					$(INSTALLABLECHECKBOX).trigger('change');
					
					$(FAILEDDEPCHECKBOX).attr('checked', true);
					$(FAILEDDEPCHECKBOX).attr('disabled', false);
					$(FAILEDDEPCHECKBOX).trigger('change');
					
					$(COMBINEDCHECKBOX).attr('checked', true);
                    $(COMBINEDCHECKBOX).attr('disabled', false);
                    $(COMBINEDCHECKBOX).trigger('change');
					
					if (groupItem && groupItem.hasOwnProperty("group_state")) {
						if (groupItem.group_state != "INSTALLDONE") {
							$(INSTALLEDCHECKBOX).attr('checked', false);
							$(INSTALLEDCHECKBOX).attr('disabled', true);
							$(INSTALLEDCHECKBOX).trigger('change');
						} else {
							$(INSTALLEDCHECKBOX).attr('checked', true);
							$(INSTALLEDCHECKBOX).attr('disabled', false);
							$(INSTALLEDCHECKBOX).trigger('change');
						}
					}
					
					$(RUNBACKCHECKBOX).attr('checked', false);
					$(RUNBACKCHECKBOX).attr('disabled', false);
					$(RUNBACKCHECKBOX).trigger('change');
				}
				
				function handleInvalidPath(hapi) {
				if (hapi.hcode == 5) {
					$(BROWSE_LOCATION_ERROR).html(localizer.getString('hpsum.baseline.add.inValidLocation'));
					$(PATH).addClass("hp-error");
					$(BROWSE_LOCATION_ERROR).show();
					$('#browse-dialog-cancel').trigger('click');
				    	$(GENERATE).attr("disabled", true);
				} else {
				    $(BROWSE_LOCATION_ERROR).hide();
				    $(PATH).removeClass("hp-error");
				    
				}
			}

				function onItemChange(item) {
					if (timer) {
						clearInterval(timer);
						timer = null;
					}
					groupItem = item.hapi;
					if (groupItem && groupItem.hasOwnProperty("group_id")) {
						$(TITLE).text(groupItem.group_name);	
						if(groupItem.group_state != "INSTALLDONE"){
						    $(INSTALLEDCHECKBOX).attr('checked', false);
						    $(INSTALLEDCHECKBOX).attr('disabled', true);
						    $(INSTALLEDCHECKBOX).trigger('change');
						} else {
							$(INSTALLEDCHECKBOX).attr('checked', true);
						    $(INSTALLEDCHECKBOX).attr('disabled', false);
						    $(INSTALLEDCHECKBOX).trigger('change');
						}
					} else {
						$(CANCEL).trigger('click');
					}
				}

				function showReportGenerationWait() {
					var reportButtons = {};
					reportButtons[localizer.getString('hpsum.node.runbackReport')] = function() {
						notifications.show(localizer.getString("hpsum.node.runningReportInBack") + groupItem.group_name + 
										   '. ' + localizer.getString("hpsum.node.referForReportStatus"), 'ok');
						closesReportGenerationWait();
					};
	
					reportWaitDialog = $(SPLASH_DIALOG);
					reportWaitDialog.dialog({
						modal : true,
						dialogClass : 'hp-simple-dialog',
						position : "center",
						draggable : false,
						resizable : false,
						buttons : reportButtons,
						width : 300,
						height : 180
					}); 
					
					$(SPLASH_SPINNER).show();
					reportWaitDialog.dialog('open');
				}

				function closesReportGenerationWait() {
					$(SPLASH_SPINNER).hide();
					if (reportWaitDialog) {
					   reportWaitDialog.dialog('close');
					}
				}

				function populateReportsTable(isItemOnChange) {	
					var reports = [],
					    firmware_report,
					    update_applied_report,
					    installed_report,
					    dependency_report,
					    combined_report,
					    nodes = [];

					presenter.getAllReports({
						success : function(data) {
							reports = data.hapi.reports.report;
							var tableReports = [],
							    reportTypes = [],
							    reportStatus,
							    inProgress = false;
								rept_path=data.hapi.reports.report_location;
								$(PATH).val(rept_path);
							    							    
							for (var idx = 0; idx < reports.length; ++idx) {
								    reportStatus = reports[idx].report_state;
								    
								if (reportStatus == "report_generation_completed") {
									reportStatus = localizer.getString("hpsum.node.completed");
								} else if (reportStatus == "in_progress" || reportStatus == "not_started" || reportStatus == "partially_generated") {
									reportStatus = localizer.getString("hpsum.node.inProgress");
									inProgress = true;
									if (isItemOnChange) {
										inProgressReportId = reports[idx].report_id;

										$(GENERATE).attr("disabled", true);
										inProgressTimer = setInterval(function() {
											presenter.getReportStatus(inProgressReportId, {
												success : function(data) {
													if (data.hapi.report_state.match(/in_progress|not_started|partially_generated/i)) {
													} else if (data.hapi.report_state.match(/report_generation_completed/i)) {

														clearInterval(inProgressTimer);

														$(GENERATE).attr("disabled", false);
														populateReportsTable(false);
														generateInProgress = false;

													} else {

														clearInterval(inProgressTimer);

													}
												},
												error : function(errorInfo) {

													clearInterval(inProgressTimer);
												}
											});

										}, 3000);
									}
								} else {
									reportStatus = localizer.getString("hpsum.node.failed");
								}

								    
								    reportTypes = reports[idx].report_type;
								    firmware_report = update_applied_report = 	installed_report = dependency_report = combined_report = "";					    
								    for (var i=0; i < reportTypes.length; i++) {
								    	
								    	if (reportTypes[i] == "firmware_report") {
								    		reportTypes[i] = "Firmware";
								    		if (inProgress) {
												firmware_report = '<img src="/img/hp-piano/throbber-small.png" class="hpsum-status-change-med">';
											} else { 	
								    		    firmware_report =  '<a href="' + reports[idx].report_id + '/' + reportTypes[i] + '.rpt"' + 'target ="_blank">' + 
								    		                   '<img src="/img/hp-piano/status-ok.png" ></br>' +
								    		                   localizer.getString("hpsum.node.viewDetails") + '</a>';
								    		}
								    	}
								    	else if (reportTypes[i] == "update_applied_report") {
								    		reportTypes[i] = "update_applied";
								    		if (inProgress) {
												update_applied_report = '<img src="/img/hp-piano/throbber-small.png" class="hpsum-status-change-med">';
											} else { 
								    		    update_applied_report =  '<a href="' + reports[idx].report_id + '/' + reportTypes[i] + '.rpt"' + 'target ="_blank">' +
								    		                      '<img src="/img/hp-piano/status-ok.png" ></br>' +
								    		                      localizer.getString("hpsum.node.viewDetails") + '</a>';
								    		}
								    	}
								    	else if (reportTypes[i] == "installed_report") {
								    		reportTypes[i] = "Installed";
								    		if (inProgress) {
												installed_report = '<img src="/img/hp-piano/throbber-small.png" class="hpsum-status-change-med">';
											} else { 
								    		    installed_report =  '<a href="' + reports[idx].report_id + '/' + reportTypes[i] + '.rpt"' + 'target ="_blank">' +
								    		                    '<img src="/img/hp-piano/status-ok.png" ></br>' +
								    		                     localizer.getString("hpsum.node.viewDetails") + '</a>';
								    		}
								    	}
								    	else if (reportTypes[i] == "dependency_report") {
								    		reportTypes[i] = "FailedDependency";
								    		if (inProgress) {
												dependency_report = '<img src="/img/hp-piano/throbber-small.png" class="hpsum-status-change-med">';
											} else { 
								    		    dependency_report =  '<a href="' + reports[idx].report_id + '/' + reportTypes[i] + '.rpt"' + 'target ="_blank">' +
								    		                     '<img src="/img/hp-piano/status-ok.png" ></br>' +
								    		                   localizer.getString("hpsum.node.viewDetails") + '</a>';
								    		}
								    	}
								    	else if (reportTypes[i] == "combined_report") {
                                            reportTypes[i] = "Combined";
                                            if (inProgress) {
                                                combined_report = '<img src="/img/hp-piano/throbber-small.png" class="hpsum-status-change-med">';
                                            } else { 
                                                combined_report =  '<a href="' + reports[idx].report_id + '/' + reportTypes[i] + '.rpt"' + 'target ="_blank">' +
                                                                 '<img src="/img/hp-piano/status-ok.png" ></br>' +
                                                               localizer.getString("hpsum.node.viewDetails") + '</a>';
                                            }
                                        }
								    }
								    
								    inProgress = false;
								
								var deleteReport = '<a id="hpsum-delete-report" data-custom-value="' + reports[idx].report_id + '">' +
								'<img src="/img/hp-piano/close.png" >' + '</a>';
								
								tableReports.push({
									time_stamp : reports[idx].date_and_time,
									report_path:reports[idx].report_path,
									report_format : reports[idx].report_format,
									firmware_type : firmware_report,
									update_applied_type : update_applied_report,
									installed_type : installed_report,
									dependency_type : dependency_report,
									combined_report : combined_report,
									report_status : reportStatus,
									node_name : reports[idx].node_id,
									delete_report : deleteReport
								});
							}
									    
							$(REPORTS_TABLE).dataTable().fnClearTable();
							$(REPORTS_TABLE).dataTable().fnAddData(tableReports);
						},
						error : function(data) {
							notifications.show(data.hapi.hmessage, 'error');
							$(CANCEL).trigger('click');
						}
					});
				};

					
				function onGenerate() {	
					generateInProgress = true;
					$(GENERATE).attr("disabled", true);
					if (!$(RUNBACKCHECKBOX).is(':checked')) {
						showReportGenerationWait();
					}

					var request,
					    firmwaretype = "false",
					    update_appliedtype = "false",
					    faileddeptype = "false",
					    installedtype = "false",
					    combinedtype = "false",
					    reportformat = "false";

					if ($(REPORTFORMATHTML).is(':checked')) {
						reportformat = $(REPORTFORMATHTML).val();
					} else if ($(REPORTFORMATXML).is(':checked')) {
						reportformat = $(REPORTFORMATXML).val();
					} else if ($(REPORTFORMATCSV).is(':checked')) {
						reportformat = $(REPORTFORMATCSV).val();
					}

					if ($(FIRMWARECHECKBOX).is(':checked')) {
						firmwaretype = "true";
					}
					if ($(INSTALLABLECHECKBOX).is(':checked')) {
						update_appliedtype = "true";
					}
					if ($(FAILEDDEPCHECKBOX).is(':checked')) {
						faileddeptype = "true";
					}
					if ($(INSTALLEDCHECKBOX).is(':checked')) {
						installedtype = "true";
					}
					if ($(COMBINEDCHECKBOX).is(':checked')) {
                        combinedtype = "true";
                    }
					
					var requestNodeArray = [],
						reportNodes = groupItem.group_nodes.group_node;
						
					for (var i=0; i<reportNodes.length; i++){
						requestNodeArray.push({
									node_id : reportNodes[i],
									firmware_report : firmwaretype,
									update_applied_report : update_appliedtype,
									dependency_report : faileddeptype,
									installed_report : installedtype,
									combined_report : combinedtype
						});
					}
                    
					var request = {
						hapi : {
							report_format : reportformat,
							baseline_report: "false",
							nodes : {
								node : requestNodeArray
							}
						}
					};

					var requestSetSessionAttribute = {
						hapi : {
							report_dir : $(PATH).val()
							}
					};
					
					if ( rept_path.toLowerCase() != $(PATH).val().toLowerCase() ) {
					presenter.setSessionAttribute(requestSetSessionAttribute, {
						success : function(data) {
							createRepPresenter(request)	;
					
						},
						error : function(errorInfo) {
							closesReportGenerationWait();
							$(BROWSE_LOCATION_ERROR).show();
							$(BROWSE_LOCATION_ERROR).html(localizer.getString('hpsum.baseline.add.errorReportText'));
							$(PATH).addClass('hp-error');
							$(GENERATE).attr("disabled", true);
							}
						});
					}
					else
					{
						createRepPresenter(request)	;
					}

				}
				function createRepPresenter(request)
				{
					presenter.createReport(request, {
						success : function(data) {
							onSuccessReportCreation(data.hapi.report_id);
						},
						error : function(errorInfo) {
							notifications.show(errorInfo, 'error');
							closesReportGenerationWait();
							$(CANCEL).trigger('click');
						}
					});
				}
				
				function initBrowseDialog(){
				
            	var dialogView = new DialogView();
                dialogView.init({contents: browseDialogContents,
                	position : "center",
                    ok: function (elem) {
                    	
                    	var node = $(BROWSE_TREE).jstree('get_selected');
						if(node.length == 0){
                             node=node.prevObject;
							 }
                    	if(node[0] == null )
                    	{
                    		showInfoDialog();
	                    	return false;
                    		
                    	}
                    	$(PATH).val(node[0].id);
                    	var path = $(PATH).val();
                    	path = path.replace("_C_", ":");
                    	$(PATH).val(path);
                    	$(PATH).trigger('change');
                    },
                    cancel: function () {
                    	$(PATH).val(rept_path);
                    	$(PATH).trigger('change');
                    }
                });
            }
			
			function showInfoDialog()
            {
            	if (!infoDialog) {
                    infoDialog =  $(INFO_DIALOG);
                    infoDialog.dialog({
                        modal : true,
                        dialogClass: 'hp-simple-dialog',
                        position : "center",
                        draggable : false,
                        resizable : false
                    });
                    $('button', infoDialog).on('click', function () {
                        infoDialog.dialog('close');
                    });
                }
                infoDialog.dialog('open');
            }
			function createTree(){
            	
            	var uri = "Session/" + session.getToken()  + "/Baseline/browse";
				var initial_folder = $(PATH).val();
				
				$(BROWSE_TREE).empty();
                $(BROWSE_TREE).jstree({
                        "json_data" : {
                        		   "ajax" : {
						           		"url" : function (node) {
	                                        var url;
	                                        if (node == -1) {
	                                            url = "Session/" + session.getToken()  + "/Baseline/browse";
	                                        } else {
	                                            url = null;
	                                        }
	                                        return url;
	                                    },
										"type" : "POST",
					                    "dataType" : "json",
					                    "data" : function (n) {
					                    	var uri = $(PATH).val().length > 0 ? $(PATH).val() : "..";
					                    	uri = uri.replace("_C_", ":"); 
												var object = {
														"hapi": {
    														"uri": uri
														}
													}; 
												
												return JSON.stringify(object); 
										},
										"success" : function (output) {
											
											var data = [], children = [], index, node, bAddParent = false;
											
											//This will handle if user has given an invalid location to browse.
											handleInvalidPath(output.hapi);
											
											//hcode has string value in the response payload. This need to be changed later when it is 
											//changed to integer value
											if(output.hapi.hcode != "0" || output.hapi.folders.folder.length == 0 )
											{
												//add a node to navigate to parent directory 
												node = {
											        		"data" : "..",
											        		"attr" : { "id" : "..", "rel" : "parent"},
											                "state" : "open"
											               };
											               
											    data.push( node );
												return data;
											}
											
											//iterate through folders and create child nodes
											for(var i=0; i < output.hapi.folders.folder.length; i++ ){
												var folder = output.hapi.folders.folder[i];
												var child, rel;
												
												if(i === 0) 
												{
													var str = $(PATH).val();
																										
													bAddParent = true;
													
												}	
												
												//if it is root folder and drive, add the first item as a sibling node instead of parent node
												//change icon if folder is a valid package
												
												
												//take only last folder name from complete path
												//var str = folder.folder_name.substring(folder.folder_name.lastIndexOf('/')+1);
												var strfolder, idfolder;
												if(str === '/' && folder.folder_name.indexOf('/') != 0) {
													strfolder = folder.folder_name.substring(0, folder.folder_name.indexOf('/')-1);
													idfolder = folder.folder_name.substring(0, folder.folder_name.indexOf('/'));
												}
												else {
												strfolder = folder.folder_name.substring(folder.folder_name.lastIndexOf('/')+1);
												idfolder = folder.folder_name;
												}
												idfolder = idfolder.replace(":", "_C_");
												//create children nodes
												if ( i > 0 || str === '/' ) {
												if(strfolder.length > 0 && idfolder.length > 0) {
    									        	child = {
    									        		"data" : strfolder,
    									        		 "attr" : {"id" : idfolder, "rel" : rel}
    									        		};
    										        children.push( child );
													}
    										    }
										    }
											
											//add a node to navigate to parent directory 
											node = {
										        		"data" : "..",
										        		"attr" : { "id" : "..", "rel" : "parent"},
										                "state" : "open",
										               };
										               
										    
										    
										    if(bAddParent) {
										    	var rel, val;
										    	
													
												if($(PATH).val() === '')
													val = output.hapi.folders.folder[0].folder_name;
												else
												{
													
													if ( initial_folder.length > 0 ) 
													{
														var repSlash = $(PATH).val().split('\\').join('/');
														val = repSlash;
														initial_folder="";
													}
													else
														val = $(PATH).val();
													
												}
												
												var valId = val; 
												valId = valId.replace(":", "_C_");
												val = val.replace("_C_", ":");
												if ( val[0] =='/' && navigator.appVersion.indexOf("Win") != -1  )   
												{
													val = "";
													rel = "folder";
												}
												else
												{
													if ( val != '/' )
													data.push( node );
												}
											    //add parent folder to folder list
												node = {
											        		"data" : val,//output.hapi.folders.folder[0].folder_name,
											        		"attr" : { "id" : valId, "rel" : rel}, //{ "id" : output.hapi.folders.folder[0].folder_name, "rel" : rel},
											                "metadata" :  output.hapi.folders.folder[0],
											                "state" : "open",
											                "children" : children
											               };
											               
											    data.push( node );
											}
											else
											{
												data.push(children);
											}
											
										                
											return data;
										}
						           }
						},
                        "themes" : {
                                "theme" : "default",
                                "url" : "/css/style.css",
                                "dots" : true,
                                "icons" : true
                        },
                        "plugins" : [ "themes", "json_data", "ui" , "crrm", "types" ],
                        "types" : {
                                "max_depth" : -2,
                                "max_children" : -2,
                                "valid_children" : [ "drive" ],
                                "types" : {
                                        "default" : {
                                                "valid_children" : "none",
                                                "icon" : {
                                                        "image" : "/img/hp-piano/collapse-closed.png"
                                                }
                                        },
                                        "folder" : {
                                                "valid_children" : [ "default", "folder", "package" ],
                                                "icon" : {
                                                        "image" : "/img/hp-piano/collapse-closed.png"
                                                }
                                        },
                                        "package" : {
                                                "valid_children" : [ "default", "folder" ],
                                                "icon" : {
                                                        "image" : "/img/hp-piano/status-ok.png"
                                                }
                                        },
                                        "drive" : {
                                                "valid_children" : [ "default", "folder" ],
                                                "icon" : {
                                                        "image" : "/img/hp-piano/down-arrow.png"
                                                },
                                                "start_drag" : false,
                                                "move_node" : false,
                                                "delete_node" : false,
                                                "remove" : false
                                        },
                                        "parent" : {
                                                "valid_children" : [ "default", "folder", "drive", "package" ],
                                                "icon" : {
                                                        "image" : "/img/hp-piano/grid-collapse.png"
                                                },
                                                "start_drag" : false,
                                                "move_node" : false,
                                                "delete_node" : false,
                                                "remove" : false
                                        }
                                        
                                }
                        }
                })
                .bind("click.jstree", function (event, data) {
                		var node = $(BROWSE_TREE).jstree('get_selected');
                		if(node[0].id === "..")
                		{
                			if(node[0].nextSibling)
                			{
                				var str = $(PATH).val(); 
                				if(str === '')
                				{
                					$(PATH).val(node[0].nextSibling.id.substring(0, node[0].nextSibling.id.lastIndexOf("/")));
                					$(PATH).trigger('change');
                				}
                				else if(str === '/')
                				{
                					
                				}
                				else
                				{
	                				if(str.indexOf('/') != -1){
	                					$(PATH).val(node[0].nextSibling.id.substring(0, node[0].nextSibling.id.lastIndexOf("/")));
										var root_path = $(PATH).val();
										if ( root_path == '' )
											$(PATH).val("/");
	                					$(PATH).trigger('change');
	                				}
	                				else{
	                					$(PATH).val("/");
	                					$(PATH).trigger('change');
	                				}
	                			}
                			}
                			else
                			{
                				$(PATH).val("/");
                				$(PATH).trigger('change');
                			}
                		}
                		else 
                		{	
                    		$(PATH).val(node[0].id);
                    		$(PATH).trigger('change');
                    	}
                		
                		$(BROWSE_TREE).jstree("refresh");
                })
                .bind("reselect.jstree", function (event, data) {
                    var node = $(BROWSE_TREE).jstree('get_selected');
                    
                })
                .bind("select_node.jstree", function (event, data) { 
				
                    var node = $(BROWSE_TREE).jstree('get_selected');
                                   
                        if(node[0].id ==".."|| node[0].id=="/")
                            $(BROWSE_OK).attr("disabled","disabled");
                        else
                            $(BROWSE_OK).removeAttr("disabled");
                        });
                    
                        
                }

				function getReportStatus(reportId) {
					if (timer) {
						clearInterval(timer);
						timer = null;
					}
					timer = setInterval(function() {
						presenter.getReportStatus(reportId, {
							success : function(data) {
								if (data.hapi.report_state.match(/in_progress|not_started/i)) {
								} else if (data.hapi.report_state.match(/report_generation_completed/i)) {
									closesReportGenerationWait();
									if (timer) {
										clearInterval(timer);
										timer = null;
									}
									$(GENERATE).attr("disabled", false);
									populateReportsTable(false);
									generateInProgress = false;
								} else if (data.hapi.report_state.match(/partially_generated/i)) {
									
								} else {
									notifications.show(data.hapi.hmessage, 'error');
									closesReportGenerationWait();
									
									if (timer) {
										clearInterval(timer);
										timer = null;
									}

									$(CANCEL).trigger('click');
								}
							},
							error : function(errorInfo) {
								notifications.show(errorInfo, 'error');
								closesReportGenerationWait();
								
								if (timer) {
									clearInterval(timer);
									timer = null;
								}

								$(CANCEL).trigger('click');
							}
						});

					}, 3000);
				}

				function onSuccessReportCreation(reportId) {
					populateReportsTable(false);
					presenter.generateReport(reportId, {
						success : function(data) {
							if (!$(RUNBACKCHECKBOX).is(':checked')) {
								populateReportsTable(false);
								getReportStatus(reportId);
							} else {
								notifications.show(localizer.getString("hpsum.node.runningReportInBack") + groupItem.group_name +
												   '. ' + localizer.getString("hpsum.node.referForReportStatus"), 'ok');
							    populateReportsTable(false);
								getReportStatus(reportId);
							}
						},
						error : function(errorInfo) {
							notifications.show(errorInfo, 'error');
							closesReportGenerationWait();
							$(CANCEL).trigger('click');
						}
					});
				}

				function onDeleteReport() {
					var deleteConfirmButtons = {};

					deleteConfirmButtons[localizer.getString('core.delete.delete_button')] = function() {
						presenter.deleteReport({report_id : deleteReportId},
							{
							success : function(data) {
								notifications.show(data.hapi.hmessage, 'ok');
								populateReportsTable(false);
							},
							error : function(message) {
								notifications.show(message, 'error');
							}
						});
						deleteInfoDialog.dialog('close');
					};

					deleteConfirmButtons[localizer.getString('core.delete.cancel_button')] = function() {
						deleteInfoDialog.dialog('close');
					};
					
					if (!deleteInfoDialog) {
						deleteInfoDialog = $('#hpsum-delete-report-dialog');
						deleteInfoDialog.dialog({
							modal : true,
							dialogClass : 'hp-simple-dialog',
							position : "center",
							draggable : false,
							resizable : false,
							buttons : deleteConfirmButtons
						});
					}
					
					deleteInfoDialog.dialog('open');	
				}
				
				function changeLocation(location) {
					if (location.length > ROUTE_PREFIX.length) {
						$(PANELS).hpStackedPanels('setPanelByLocation', '#' + location);
					} else {
						$(PANELS).hpStackedPanels('setFirstPanel');
					}
				}


				this.init = function() {
				browseDialogContents = $(BROWSE_DIALOG).detach().show();
				$('#hpsum-report-location-text').html(localizer.getString('hpsum.baseline.add.browseReportText'));
				$('#hpsum-report-location-text').removeClass('hp-collapsed');
				
				$(PATH).bind('keyup', function(){
					var path=$(PATH).val();
					if( path=="" ){
							$(BROWSE_LOCATION_ERROR).show();
							$(BROWSE_LOCATION_ERROR).html(localizer.getString('hpsum.baseline.add.emptyReportText'));
							$(PATH).addClass('hp-error');
							$(GENERATE).attr("disabled", true);
						}
						else
						{
							$(BROWSE_LOCATION_ERROR).hide();
							$(PATH).removeClass('hp-error');
							$(GENERATE).attr("disabled", false);
						}
		            		});
				
				$(PATH).bind('change',function(){
					var path=$(PATH).val();
						if( path=="" ){
							$(BROWSE_LOCATION_ERROR).show();
							$(BROWSE_LOCATION_ERROR).html(localizer.getString('hpsum.baseline.add.emptyReportText'));
							$(PATH).addClass('hp-error');
							$(GENERATE).attr("disabled", true);
						}
						else
						{
							$(BROWSE_LOCATION_ERROR).hide();
							$(PATH).removeClass('hp-error');
							$(GENERATE).attr("disabled", false);
						}
				});
				
                $(BROWSE_BUTTON).on('click', function() {
				
                initBrowseDialog();
				
                    createTree();
                });
					var resource = router.location().split('/');
                	resource = resource[1];
              	$('a[data-panel-id]').each(function(index) {
                		var currentLink = $(this).attr('href');
                		if(currentLink  == undefined)
                			return;
                		var current = currentLink.split('/');
                		current[1] = resource;
                		currentLink =current.join('/');
                		$(this).attr('href',currentLink);
  					});
  					ROUTE_PREFIX = '/'+ resource +'/reports';

					$(PANELS).hpStackedPanels({
						panelSelector : PANEL_SELECTOR
					});

					$(RESET).live('click', function() {
						reset.call();
					});

					$(GENERATE).live('click', function(ev) {
						var path=$(PATH).val();
						if (!generateInProgress && path != "") {
						 onGenerate.call();
						}
						else
						$(GENERATE).attr("disabled", true);
						ev.preventDefault();
					});
					
					$('#hpsum-delete-report').live('click', function(ev) {
						deleteReportId = $(this).data("custom-value");
						onDeleteReport.call();
						ev.preventDefault();
					});
					
					
					
					$(CANCEL).click(function () {
					if (timer) {
						clearInterval(timer);
						timer = null;
					}
					if (inProgressTimer) {
						clearInterval(inProgressTimer);
						inProgressTimer = null;
					}
					
                    router.go(urlFragment.replaceView(router.location(), 'show'));
                });
					router.watch('node report section', ROUTE_PREFIX + '.*', {
						parent : ROUTE_PREFIX,
						change : changeLocation
					});
					
					this.resume();
				};

				this.resume = function() {
					
					var dummyReportsData = [];
					$(REPORTS_TABLE).dataTable({
						oLanguage : {
						    sEmptyTable: localizer.getString("hpsum.node.noReports"),
						    sSearch: localizer.getString('hpsum.common.search')
						},
						bPaginate : false,
						bFilter : false,
						bInfo : false,
						bAutoWidth : false,
						bRetrieve : true,
						bDestroy : true,
						aaData : dummyReportsData,
						aoColumns : [{
							mDataProp : 'time_stamp'
						},{
							mDataProp : 'report_path'
						},{
							sWidth: 75, mDataProp : 'firmware_type'
						},{
							sWidth: 75, mDataProp : 'update_applied_type'
						},{
							sWidth: 75, mDataProp : 'dependency_type'
						},{
							sWidth: 75, mDataProp : 'installed_type'
						},{
                            sWidth: 75, mDataProp : 'combined_report'
                        },{
							mDataProp : 'report_format'
						},{
							mDataProp : 'report_status'
						},{
							mDataProp : 'delete_report'
						}],
						aaSorting: [[ 0, "desc" ]]
					});
					
					generateInProgress = false;
					if (timer) {
						clearInterval(timer);
						timer = null;
					}
					if (inProgressTimer) {
						clearInterval(inProgressTimer);
						inProgressTimer = null;
					}
					$(RESET).trigger('click');	    
					groupPresenter.on("itemChange", onItemChange);
					$(PANELS).hpStackedPanels('resume');
					$(GENERATE).attr("disabled", false);
					$(BROWSE_LOCATION_ERROR).hide();
					$(PATH).removeClass('hp-error');
					populateReportsTable(true);
				};

				this.pause = function() {
					
					if (timer) {
						clearInterval(timer);
						timer = null;
					}
					groupPresenter.off("itemChange", onItemChange);
					$(PANELS).hpStackedPanels('pause');
				};

			}

			return GroupReportsShowView;
		}());

	return new GroupReportsShowView();

});



